@@ -1,19 +1,19 @@
 // plotters-iced
 //
 // Iced backend for Plotters
-// Copyright: 2021, Joylei <leingliu@gmail.com>
+// Copyright: 2022, Joylei <leingliu@gmail.com>
 // License: MIT
 use iced_graphics::canvas;
 use iced_native::{Color, Point};
 use plotters_backend::{BackendColor, BackendCoord, BackendStyle};
 
-#[inline(always)]
+#[inline]
 pub(crate) fn cvt_color(color: &BackendColor) -> Color {
     let ((r, g, b), a) = (color.rgb, color.alpha);
     Color::from_rgba8(r, g, b, a as f32)
 }
 
-#[inline(always)]
+#[inline]
 pub(crate) fn cvt_stroke<S: BackendStyle>(style: &S) -> canvas::Stroke {
     canvas::Stroke::default()
         .with_color(cvt_color(&style.color()))
@@ -25,14 +25,14 @@ pub(crate) trait CvtPoint {
 }
 
 impl CvtPoint for BackendCoord {
-    #[inline(always)]
+    #[inline]
     fn cvt_point(self) -> Point {
         Point::new(self.0 as f32, self.1 as f32)
     }
 }
 
 impl CvtPoint for [f64; 2] {
-    #[inline(always)]
+    #[inline]
     fn cvt_point(self) -> Point {
         Point::new(self[0] as f32, self[1] as f32)
     }
