@@ -1,7 +1,7 @@
 // plotters-iced
 //
 // Iced backend for Plotters
-// Copyright: 2021, Joylei <leingliu@gmail.com>
+// Copyright: 2022, Joylei <leingliu@gmail.com>
 // License: MIT
 
 use crate::Chart;
@@ -11,6 +11,18 @@ use iced_native::{
 use plotters_backend::{FontFamily, FontStyle};
 use std::{hash::Hash, marker::PhantomData};
 
+/// Signature for the callback that ChartWidget can trigger when a mouse event
+/// happens inside its layout. Return None if the mouse event is not being
+/// handled by this callback.
+///
+/// # Arguments
+///
+/// * The type of mouse event
+/// * The cursor position during the event, relative to the widget origin. Use
+///   the chart coord spec to transform this point into the chart's data coordinates.
+pub type MouseEventCallback<Message> =
+    Box<dyn Fn(iced_native::mouse::Event, Point) -> Option<Message>>;
+
 /// Chart container, turns [`Chart`]s to [`Widget`]s
 pub struct ChartWidget<Message, C>
 where
@@ -20,6 +32,7 @@ where
     width: Length,
     height: Length,
     font_resolver: Box<dyn Fn(FontFamily, FontStyle) -> Font>,
+    on_mouse_event: Option<MouseEventCallback<Message>>,
     _marker: PhantomData<Message>,
 }
 
@@ -34,6 +47,7 @@ where
             width: Length::Fill,
             height: Length::Fill,
             font_resolver: Box::new(|_, _| Default::default()),
+            on_mouse_event: None,
             _marker: Default::default(),
         }
     }
@@ -58,6 +72,12 @@ where
         self.font_resolver = Box::new(resolver);
         self
     }
+
+    #[inline(always)]
+    pub fn on_mouse_event(mut self, callback: MouseEventCallback<Message>) -> Self {
+        self.on_mouse_event = Some(callback);
+        self
+    }
 }
 
 impl<'a, Message, Renderer, C> Widget<Message, Renderer> for ChartWidget<Message, C>
@@ -65,17 +85,15 @@ where
     C: Chart<Message>,
     Renderer: self::Renderer,
 {
-    #[inline(always)]
     fn width(&self) -> Length {
         self.width
     }
 
-    #[inline(always)]
     fn height(&self) -> Length {
         self.height
     }
 
-    #[inline(always)]
+    #[inline]
     fn layout(
         &self,
         _renderer: &Renderer,
@@ -117,6 +135,20 @@ where
         clipboard: &mut dyn Clipboard,
         messages: &mut Vec<Message>,
     ) -> event::Status {
+        if let iced_native::Event::Mouse(mouse_event) = &event {
+            if let Some(callback) = &self.on_mouse_event {
+                let bounds = layout.bounds();
+                if bounds.contains(cursor_position) {
+                    let p_origin = bounds.position();
+                    let p = cursor_position - p_origin;
+                    if let Some(message) = callback(*mouse_event, Point::new(p.x, p.y)) {
+                        messages.push(message);
+                        return event::Status::Captured;
+                    }
+                }
+            }
+        }
+
         renderer.on_event(
             &mut self.chart,
             event,
@@ -127,7 +159,7 @@ where
         )
     }
 
-    #[inline(always)]
+    #[inline]
     fn hash_layout(&self, state: &mut iced_native::Hasher) {
         struct Marker;
         std::any::TypeId::of::<Marker>().hash(state);
@@ -166,7 +198,6 @@ where
     C: Chart<Message> + 'a,
     Renderer: self::Renderer,
 {
-    #[inline(always)]
     fn from(widget: ChartWidget<Message, C>) -> Self {
         Element::new(widget)
     }
