@@ -1,7 +1,7 @@
 // plotters-iced
 //
 // Iced backend for Plotters
-// Copyright: 2021, Joylei <leingliu@gmail.com>
+// Copyright: 2022, Joylei <leingliu@gmail.com>
 // License: MIT
 
 #[cfg(target_arch = "wasm32")]
@@ -36,7 +36,7 @@ impl RotateAngle for FontTransform {
             FontTransform::Rotate180 => Some(180.0),
             FontTransform::Rotate270 => Some(270.0),
             FontTransform::Rotate90 => Some(90.0),
-            &FontTransform::RotateAngle(v) => Some(v),
+            //&FontTransform::RotateAngle(v) => Some(v),
             _ => None,
         }
     }
