@@ -1,7 +1,7 @@
 // plotters-iced
 //
 // Iced backend for Plotters
-// Copyright: 2021, Joylei <leingliu@gmail.com>
+// Copyright: 2022, Joylei <leingliu@gmail.com>
 // License: MIT
 
 use super::{svg::SvgBackend, AsBumpStr};
@@ -31,7 +31,6 @@ where
     C: Chart<Message>,
 {
     /// create chart widget
-    #[inline(always)]
     pub fn new(chart: C) -> Self {
         Self {
             chart,
@@ -42,7 +41,7 @@ where
     }
 
     /// only support fixed size for wasm
-    #[inline(always)]
+    #[inline]
     pub fn width(mut self, width: Length) -> Self {
         match width {
             Length::Units(width) => {
@@ -56,7 +55,7 @@ where
     }
 
     /// only support fixed size for wasm
-    #[inline(always)]
+    #[inline]
     pub fn height(mut self, height: Length) -> Self {
         match height {
             Length::Units(height) => {
@@ -70,7 +69,7 @@ where
     }
 
     /// stub for API compatible
-    #[inline(always)]
+    #[inline]
     pub fn resolve_font(self, _resolver: impl Fn(FontFamily, FontStyle) -> Font + 'static) -> Self {
         self
     }
@@ -89,23 +88,11 @@ where
         _style_sheet: &mut Css<'b>,
     ) -> dodrio::Node<'b> {
         use dodrio::builder::*;
-        use std::collections::hash_map::DefaultHasher;
-        use std::hash::{Hash, Hasher};
         let mut nodes = Vec::new();
         let backend = SvgBackend::new(bump, (self.width as u32, self.height as u32), &mut nodes);
         self.chart.draw_chart(backend.into());
 
-        // use ptr as id
-        let ptr = &self.chart as *const C;
-        let mut h = DefaultHasher::new();
-        ptr.hash(&mut h);
-        let id = bumpalo::format!(
-            in bump,
-            "chart-{}", h.finish()
-        )
-        .into_bump_str();
         let node = svg(bump)
-            .attr("id", id)
             .attr(
                 "style",
                 bumpalo::format!(
@@ -128,7 +115,7 @@ where
     Message: 'static,
     C: Chart<Message> + 'a,
 {
-    #[inline(always)]
+    #[inline]
     fn from(widget: ChartWidget<Message, C>) -> Self {
         Element::new(widget)
     }
